@@ -6,7 +6,7 @@ Date::Fmtstr2time - Functions to format date/time strings into a Perl Time based
 
 Jim Turner
 
-(c) 2015, Jim Turner under the same license that Perl 5 itself is.  All rights reserved.
+(c) 2015-2019, Jim Turner under the same license that Perl 5 itself is.  All rights reserved.
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,7 @@ value (a large integer equivalent to the number of seconds since 1980) or an err
 
 =over 4
 
-=item <$integer> = B<str2time>(I<data-string>, I<format-string>);
+=item $integer = B<str2time>(I<data-string>, I<format-string>);
 
 Returns a standard Perl (Unix) "time" value (a large integer) on success, or an error message 
 string on failure.  One can easily check for failure by checking the result for any non-integer 
@@ -38,7 +38,7 @@ the software what format to expect the date / time value in the I<data-string> t
 
 For example:
 
-	$s = B<str2time>('01-09-2016 01:20 AM (Sat) (January)', 'mm-dd-yyyy hh:mi PM (Day) (Month)');
+	$s = &str2time('01-09-2016 01:20 AM (Sat) (January)', 'mm-dd-yyyy hh:mi PM (Day) (Month)');
 
 would set $s to 1452324000, (the Unix time equivalent).
 
@@ -49,29 +49,36 @@ number of combinations to produce the desired results.  They are listed below:
 
 =over 4
 
-B<a>, B<A>, B<am>, B<AM> - Assume hour is AM (if 1-11), and convert 12 to midnight (0 in 
-24-hour time).  (all specifiers are identical). 
+B<a>, B<A>, B<am>, or B<AM> - Assume hour is AM (if 1-11), and convert 12 to midnight 
+(0 in 24-hour time).  (all specifiers are identical and case insensitive).  See also:  
+B<p>, B<P>, B<pm>, or B<PM> below.
 
-B<day> - Three letter abbreviation of the day of the week in all lower case, ie. "sun". 
+B<day>, B<Day>, or B<DAY> - Three letter abbreviation of the day of the week 
+(case insensitive), ie. "sun".  Reason for the three versions is to match up with 
+L<Date::Time2fmtstr>, which has three separate versions for I<outputting> the desired case, 
+but here (I<inputting>), case doesn't matter.  This applies also to Month, etc. and 
+similiarly to functions that pad or don't pad with leading zeros!
 
-B<Day> - Three letter abbreviation of the day of the week capitalized, ie. "Sun". 
+B<dayofweek>, B<Dayofweek>, or B<DAYOFWEEK> - Day of the week (case insensitive).
 
-B<DAY> - Three letter abbreviation of the day of the week all capitalized, ie. "SUN". 
+B<ddd> - Number of days since beginning of year.  NOTE:  This is calculated by adding 
+the number of SECONDS (86400 per day) to midnight, 1/1/current-year, so if spanning a 
+daylight-savings time boundary may result in +1 hour difference, which the underlying 
+Perl localtime/timelocal functions will take into account!  For example, if the current 
+time was "1570286966" (2019/10/05 09:49:26), the following code:
 
-B<dayofweek> - Day of the week in all lower case, ie. "sunday". 
+print &time2str(&str2time(&time2str(1570286966, 'ddd, hh:mi:ss'), 'ddd, hh:mi:ss'), 'yyyy/mm/dd hh:mi:ss') . "\n";
 
-B<Dayofweek> - Day of the week capitalized, ie. "Sunday". 
+would print "2019/10/05 10:49:26" due to the fact that 1 hour (3600 seconds) was 
+automatically skipped over when DST was imposed between 1 January and 5 October.  This 
+"feature" only applies when calculating the date/time based on days since beginning 
+of the year ("ddd").
 
-B<DAYOFWEEK> - Day of the week all capitalized, ie. "SUNDAY". 
-
-B<ddd> - Num. of days since beginning of year.
-
-B<dd> - Day of month (2 digits, left padded with a zero if needed), ie. "03" for March.
+B<dd>, B<d1> - Day of month (1 or 2 digits, left padded with a zero if needed), ie. 
+"3" or "03" for March.
 
 B<d0>, B<d> - Numeric day of the week zero-based (Sunday=0, Monday=1, ... Saturday=6). 
 
-B<d1> - Day of month (1 or 2 digits, as needed), ie. "3" for March. 
-
 B<hh>, B<h1> - Hour in common format, ie. 1-12 (1 or 2 digits, as needed). 
 (see B<AM> and B<PM> specifiers).
 
@@ -97,25 +104,19 @@ B<mmddyy> - Numeric date in 6 digits, ie. "010715" for January 7, 2015.
 
 B<mmddyyyy> - Numeric date in 8 digits, ie. "01072015" for January 7, 2015. 
 
+B<mmmm>, B<mmm0> - Minutes since start of day (0-3599). 
+
 B<mmyy> - Numeric date in 4 digits, ie. "0115" for January, 2015. 
 
 B<mmyyyy> - Numeric date in 6 digits, ie. "012015" for January, 2015. 
 
-B<mmmm>, B<mmm0> - Minutes since start of day (0-3599). 
+B<mon>, B<Mon>, or B<MON> - Three letter abbreviation of the month (case insensitive), 
+ie. "jan" for January. 
 
-B<mon> - Three letter abbreviation of the month, in lower case, ie. "jan" for January. 
+B<month>, B<Month>, or B<MONTH> - The Full name of the month (case insensitive), 
+ie. "january".
 
-B<Mon> - Three letter abbreviation of the month, capitalized, ie. "Jan" for January. 
-
-B<MON> - Three letter abbreviation of the month all capitalized, ie. "JAN". 
-
-B<month> - The Full name of the month in all lower case, ie. "january".
-
-B<Month> - The Full name of the month capitalized, ie. "January". 
-
-B<MONTH> - The Full name of the month all capitalized, ie. "JANUARY". 
-
-B<p>, B<P>, B<pm>, B<PM> - Assume hour is noon if 12, otherwise, convert (add 12 to) 
+B<p>, B<P>, B<pm>, or B<PM> - Assume hour is noon if 12, otherwise, convert (add 12 to) 
 1-11 to convert to PM (13-23 in 24 hour time).  (all specifiers are identical). 
 
 B<q> - Number of the quarter of the year - (1-4).
@@ -124,7 +125,7 @@ B<rm> - Roman numeral for the month (i-xii) in lower case.
 
 B<RM> - Roman numeral for the month (I-XII) in upper case. 
 
-B<ss> - Seconds since start of last minute (1 or 2 digits as needed), ie. 00-59. 
+B<ss> - Seconds since start of last minute (1 or 2 digits as needed), ie. 0-59. 
 
 B<sssss>, B<ssss0> - Seconds since start of day (0-86399) 1-5 digits as needed 
 (leading zeros ignored). 
@@ -139,18 +140,16 @@ B<yymm> - Numeric date in 4 digits, ie. "1501" for January, 2015.
 
 B<yymmdd> - Numeric date in 6 digits, ie. "150107" for January 7, 2015. 
 
+B<yyyy>, B<rrrr> - Year in 4 digits.
+
+B<yyyymm> - Numeric date in 6 digits, ie. "201501" for January, 2015. 
+
 B<yyyymmdd> - Numeric date in 8 digits, ie. "20150107" for January 7, 2015. 
 
 B<yyyymmddhhmi> - Numeric date/time in 12 digits, ie. "201501071345" for January 7, 2015 1:45pm. 
 
 B<yyyymmddhhmiss> - Numeric date/time in 14 digits, ie. "20150107134512" for January 7, 2015 1:45:12pm. 
 
-B<yyyymm> - Numeric date in 6 digits, ie. "201501" for January, 2015. 
-
-B<yyyy>, B<rrrr> - Year in 4 digits.
-
-B<yyyymmdd> - Numeric date in 8 digits, ie. "20150107" for January 7, 2015. 
-
 =back
 
 =back
@@ -159,9 +158,11 @@ B<yyyymmdd> - Numeric date in 8 digits, ie. "20150107" for January 7, 2015.
 
 Perl 5
 
+L<Time::Local>
+
 =head1 RECCOMENDS
 
-L<Date::Time2fmtstr>, L<String::PictureFormat>
+L<Date::Time2fmtstr>
 
 =head1 BUGS
 
@@ -199,11 +200,11 @@ L<http://search.cpan.org/dist/Date-Fmtstr2time/>
 
 =head1 SEE ALSO
 
-L<Date::Fmtstr2time>
+L<Date::Time2fmtstr>
 
 =head1 KEYWORDS
 
-L<Date::Fmtstr2time>, L<String::PictureFormat>, formatting, picture_clause, strings
+Date::Fmtstr2time, Date::Time2fmtstr, formatting, picture_clause, strings
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -252,7 +253,7 @@ package Date::Fmtstr2time;
 use strict;
 #use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 use Time::Local;
 
